@@ -7,6 +7,7 @@
 #' @param iteration The iteration number. This is used as an ID to set the
 #'   random number seed.
 #' @param n The length of the vector returned.
+#' @param seed An integer value to pass to \code{\link[base]{set.seed}}.
 #' @return A vector of standard normal recruitment deviations.
 #' @examples
 #' get_recdevs(1, 10)
@@ -14,8 +15,8 @@
 #' get_recdevs(2, 10)
 #' @export
 
-get_recdevs <- function(iteration, n) {
-  set.seed(21)
+get_recdevs <- function(iteration, n, seed = 21) {
+  set.seed(seed)
   x <- sample(1:1e6)[iteration]
   set.seed(x)
   rnorm(n, 0, 1)
